@@ -29,7 +29,6 @@
 #ifndef cxxtools_Http_Service_h
 #define cxxtools_Http_Service_h
 
-#include <cxxtools/http/api.h>
 #include <cxxtools/mutex.h>
 #include <cxxtools/condition.h>
 #include <vector>
@@ -51,7 +50,7 @@ class Authenticator
         virtual bool checkAuth(const Request&) const = 0;
 };
 
-class CXXTOOLS_HTTP_API Service
+class Service
 {
         std::vector<const Authenticator*> _authenticators;
         std::string _realm;
