@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2011 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -29,48 +29,102 @@
 #ifndef CXXTOOLS_JSONSERIALIZER_H
 #define CXXTOOLS_JSONSERIALIZER_H
 
-#include <cxxtools/textstream.h>
 #include <cxxtools/decomposer.h>
-#include <cxxtools/noncopyable.h>
 #include <cxxtools/jsonformatter.h>
+#include <iostream>
 #include <sstream>
 #include <stdexcept>
 
 namespace cxxtools
 {
-    class JsonSerializer : private NonCopyable
+    /**
+     * Here is a small example to use this class.
+     * @code{.cpp}
+     * #include <iostream>
+     * #include <cxxtools/jsonserializer.h>
+     * #include <cxxtools/serializationinfo.h>
+     *
+     * // define a configuration object
+     * struct Configuration
+     * {
+     *   struct Indent
+     *   {
+     *     int length;
+     *     bool useSpace;
+     *   };
+     *
+     *   std::string encoding;
+     *   std::vector<std::string> plugIns;
+     *   Indent indent;
+     * };
+     *
+     * // define how to serialize the indent struct of configuration
+     * void operator<<= (cxxtools::SerializationInfo& si, const Configuration::Indent& indent)
+     * {
+     *   si.addMember("length") <<= indent.length;
+     *   si.addMember("use_space") <<= indent.useSpace;
+     * }
+     *
+     * // define how to serialize the configuration
+     * void operator<<= (cxxtools::SerializationInfo& si, const Configuration& config)
+     * {
+     *   si.addMember("encoding") <<= config.encoding;
+     *   si.addMember("plug-ins") <<= config.plugIns;
+     *   si.addMember("indent") <<= config.indent;
+     * }
+     *
+     * int main(int argc, char* argv[])
+     * {
+     *   try
+     *   {
+     *     // create a configuration object:
+     *     Configuration config;
+     *     config.encoding = "UTF-8";
+     *     config.plugIns.push_back("python");
+     *     config.plugIns.push_back("c++");
+     *     config.plugIns.push_back("ruby");
+     *     config.indent.length = 3;
+     *     config.indent.useSpace = true;
+     *
+     *     // serialize to json
+     *     cxxtools::JsonSerializer serializer(std::cout);
+     *     serializer.beautify(true);   // this makes it just nice to read
+     *     serializer.serialize(config).finish();
+     *   }
+     *   catch (const std::exception& e)
+     *   {
+     *     std::cerr << e.what() << std::endl;
+     *   }
+     * }
+     * @endcode
+     */
+    class JsonSerializer
     {
+            // make non copyable
+            JsonSerializer(const JsonSerializer&) { }
+            JsonSerializer& operator=(const JsonSerializer&) { return *this; }
+
         public:
             JsonSerializer()
-                : _ts(0),
+                : _os(0),
                   _inObject(false)
             {
             }
 
-            explicit JsonSerializer(std::basic_ostream<cxxtools::Char>& ts)
-                : _ts(0),
+            explicit JsonSerializer(std::ostream& os)
+                : _os(0),
                   _inObject(false)
             {
-                _formatter.begin(ts);
+                begin(os);
             }
 
-            explicit JsonSerializer(std::ostream& os,
-                TextCodec<cxxtools::Char, char>* codec = 0);
-
-            ~JsonSerializer()
+            JsonSerializer& begin(std::ostream& os)
             {
-                delete _ts;
-            }
-
-            JsonSerializer& begin(std::basic_ostream<cxxtools::Char>& ts)
-            {
-                _formatter.begin(ts);
+                _os = &os;
+                _formatter.begin(os);
                 return *this;
             }
 
-            JsonSerializer& begin(std::ostream& os,
-                TextCodec<cxxtools::Char, char>* codec = 0);
-
             void finish()
             {
                 if (_inObject)
@@ -78,9 +132,10 @@ namespace cxxtools
                     _formatter.finishObject();
                     _inObject = false;
                 }
+
                 _formatter.finish();
-                if (_ts)
-                    _ts->flush();
+
+                _os->flush();
             }
 
             template <typename T>
@@ -109,7 +164,7 @@ namespace cxxtools
                 Decomposer<T> s;
                 s.begin(v);
                 s.format(_formatter);
-                _ts->flush();
+                _os->flush();
                 return *this;
             }
 
@@ -125,6 +180,10 @@ namespace cxxtools
 
             void beautify(bool sw)    { _formatter.beautify(sw); }
 
+            bool plainkey() const     { return _formatter.plainkey(); }
+
+            void plainkey(bool sw)    { _formatter.plainkey(sw); }
+
             template <typename T>
             static std::string toString(const T& type, const std::string& name, bool beautify = false)
             {
@@ -140,7 +199,7 @@ namespace cxxtools
 
         private:
             JsonFormatter _formatter;
-            std::basic_ostream<cxxtools::Char>* _ts;
+            std::ostream* _os;
             bool _inObject;
     };
 
