@@ -33,20 +33,9 @@ namespace cxxtools
 {
 namespace bin
 {
-RpcServer::RpcServer(EventLoopBase& eventLoop)
-    : _impl(new RpcServerImpl(eventLoop, runmodeChanged, *this))
-{ }
-
-RpcServer::RpcServer(EventLoopBase& eventLoop, const std::string& ip, unsigned short int port, int backlog)
-    : _impl(new RpcServerImpl(eventLoop, runmodeChanged, *this))
+RpcServerImpl* RpcServer::newImpl(EventLoopBase& eventLoop)
 {
-    listen(ip, port, backlog);
-}
-
-RpcServer::RpcServer(EventLoopBase& eventLoop, unsigned short int port, int backlog)
-    : _impl(new RpcServerImpl(eventLoop, runmodeChanged, *this))
-{
-    listen(port, backlog);
+    return new RpcServerImpl(eventLoop, runmodeChanged, *this);
 }
 
 RpcServer::~RpcServer()
@@ -54,6 +43,11 @@ RpcServer::~RpcServer()
     delete _impl;
 }
 
+void RpcServer::listen(const std::string& ip, unsigned short int port, const std::string& certificateFile, const std::string& privateKeyFile, int sslVerifyLevel, const std::string& sslCa)
+{
+    _impl->listen(ip, port, certificateFile, privateKeyFile, sslVerifyLevel, sslCa);
+}
+
 void RpcServer::addService(const ServiceRegistry& service)
 {
     std::vector<std::string> procs = service.getProcedureNames();
@@ -70,20 +64,10 @@ void RpcServer::addService(const std::string& domain, const ServiceRegistry& ser
 
     for (std::vector<std::string>::const_iterator it = procs.begin(); it != procs.end(); ++it)
     {
-        registerProcedure(domain + '\0' + *it, service.getProcedure(*it));
+        registerProcedure(domain.empty() ? *it : (domain + '\0' + *it), service.getProcedure(*it));
     }
 }
 
-void RpcServer::listen(const std::string& ip, unsigned short int port, int backlog)
-{
-    _impl->listen(ip, port, backlog);
-}
-
-void RpcServer::listen(unsigned short int port, int backlog)
-{
-    _impl->listen(std::string(), port, backlog);
-}
-
 unsigned RpcServer::minThreads() const
 {
     return _impl->minThreads();
@@ -104,5 +88,10 @@ void RpcServer::maxThreads(unsigned m)
     _impl->maxThreads(m);
 }
 
+Delegate<bool, const SslCertificate&>& RpcServer::acceptSslCertificate()
+{
+    return _impl->acceptSslCertificate;
+}
+
 }
 }
