@@ -25,6 +25,7 @@
  */
 #include "cxxtools/datetime.h"
 #include "cxxtools/timespan.h"
+#include "cxxtools/refcounted.h"
 #include <sys/time.h>
 #include <time.h>
 #include "config.h"
@@ -32,30 +33,24 @@
 namespace cxxtools
 {
 
-class ClockImpl
+class ClockImpl : public RefCounted
 {
     public:
-        ClockImpl();
+        Timespan start();
 
-        ~ClockImpl();
+        Timespan stop() const;
 
-        void start ();
+        static UtcDateTime getSystemTime();
 
-        Timespan stop();
-
-        static DateTime getSystemTime();
-
-        static DateTime getLocalTime();
+        static LocalDateTime getLocalTime();
 
         static Timespan getSystemTicks();
 
     private:
 #ifdef HAVE_CLOCK_GETTIME
         struct timespec  _startTime;
-        struct timespec  _stopTime;
 #else
         struct timeval  _startTime;
-        struct timeval  _stopTime;
 #endif
 };
 
