@@ -72,31 +72,31 @@ namespace http {
         }
     }
 
-    void HeaderParser::Event::onMethod(const std::string& method)
+    void HeaderParser::Event::onMethod(const std::string& /*method*/)
     {
     }
 
-    void HeaderParser::Event::onUrl(const std::string& url)
+    void HeaderParser::Event::onUrl(const std::string& /*url*/)
     {
     }
 
-    void HeaderParser::Event::onUrlParam(const std::string& q)
+    void HeaderParser::Event::onUrlParam(const std::string& /*q*/)
     {
     }
 
-    void HeaderParser::Event::onHttpVersion(unsigned major, unsigned minor)
+    void HeaderParser::Event::onHttpVersion(unsigned /*major*/, unsigned /*minor*/)
     {
     }
 
-    void HeaderParser::Event::onKey(const std::string& key)
+    void HeaderParser::Event::onKey(const std::string& /*key*/)
     {
     }
 
-    void HeaderParser::Event::onValue(const std::string& value)
+    void HeaderParser::Event::onValue(const std::string& /*value*/)
     {
     }
 
-    void HeaderParser::Event::onHttpReturn(unsigned ret, const std::string& text)
+    void HeaderParser::Event::onHttpReturn(unsigned /*ret*/, const std::string& /*text*/)
     {
     }
 
@@ -308,6 +308,13 @@ namespace http {
             if (token.size() >= 2 && token[token.size() - 2] == '%')
             {
                 unsigned v = (valueOfHexDigit(token[token.size() - 1]) << 4) | valueOfHexDigit(ch);
+                if (v == 0)
+                {
+                    log_warn("%00 not allowed in url");
+                    state = &HeaderParser::state_error;
+                    return;
+                }
+
                 token[token.size() - 2] = static_cast<char>(v);
                 token.resize(token.size() - 1);
                 state = &HeaderParser::state_url;
@@ -902,12 +909,12 @@ namespace http {
         }
     }
 
-    void HeaderParser::state_end(char ch)
+    void HeaderParser::state_end(char /*ch*/)
     {
         return;
     }
 
-    void HeaderParser::state_error(char ch)
+    void HeaderParser::state_error(char /*ch*/)
     {
         return;
     }
